@@ -3,7 +3,7 @@ mod rpneval;
 mod rpnprint;
 
 pub use crate::parser::{RPNExpr, ShuntingParser};
-pub use crate::rpneval::MathContext;
+pub use crate::rpneval::{MathOp, MathContext};
 
 #[cfg(test)]
 mod parser_test;
